@@ -1,8 +1,13 @@
+//
+// written by everettjf
+// email : everettjf@live.com
+// created at 2022-01-01
+//
 mod atosl;
 
+use anyhow::Result;
 use clap::Parser;
 use std::path::PathBuf;
-use anyhow::Result;
 
 #[derive(Parser, Debug)]
 #[clap(about, version, author)]
@@ -40,9 +45,14 @@ fn main() {
     let object_path = args.object_path.into_os_string().into_string().unwrap();
     let debug_mode = args.debug != 0;
 
-    let result = atosl::print_symbolize_addresses(&object_path,args.load_address, args.addresses, debug_mode);
+    let result = atosl::print_symbolize_addresses(
+        &object_path,
+        args.load_address,
+        args.addresses,
+        debug_mode,
+    );
     match result {
-        Ok(..) => {},
-        Err(err) => println!("{}",err),
+        Ok(..) => {}
+        Err(err) => println!("{}", err),
     }
-}
\ No newline at end of file
+}
